# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AFNI_BATCH_R_METADATA = Metadata(
    id="58eaf579cadf280b0a770416bff7f89183ec4670.boutiques",
    name="AFNI_Batch_R",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AfniBatchROutputs(typing.NamedTuple):
    """
    Output object returned when calling `afni_batch_r(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def afni_batch_r(
    no_restore: bool = False,
    save_workspace: bool = False,
    no_readline: bool = False,
    vanilla_mode: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> AfniBatchROutputs:
    """
    Batch mode for executing R scripts in the AFNI environment.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/AFNI_Batch_R.html
    
    Args:
        no_restore: Do not restore anything in the R workspace at startup.
        save_workspace: Save the workspace at the end of the script execution.
        no_readline: Disable reading input from the command line.
        vanilla_mode: Run R without saving the workspace at the end, restoring\
            anything, reading the site file, or acting on startup files.
        help_: Display this help message and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AfniBatchROutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(AFNI_BATCH_R_METADATA)
    cargs = []
    cargs.append("/opt/afni/src/../install/AFNI_Batch_R")
    cargs.append("R")
    cargs.append("CMD")
    cargs.append("BATCH")
    if no_restore:
        cargs.append("--no-restore")
    if save_workspace:
        cargs.append("--save")
    if no_readline:
        cargs.append("--no-readline")
    if vanilla_mode:
        cargs.append("--vanilla")
    cargs.append("--args")
    if help_:
        cargs.append("-help")
    ret = AfniBatchROutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AFNI_BATCH_R_METADATA",
    "AfniBatchROutputs",
    "afni_batch_r",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REG_RESAMPLE_METADATA = Metadata(
    id="c8dab446c9ba4372528994e3d9d6d042ba9089bb.boutiques",
    name="reg_resample",
    package="niftyreg",
    container_image_tag="vnmd/niftyreg_1.4.0:20220819",
)


class RegResampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `reg_resample(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_resampled_image: OutputPathType
    """File containing the resampled image"""
    output_resampled_blank: OutputPathType
    """File containing the resampled blank grid"""


def reg_resample(
    reference_image: InputPathType,
    floating_image: InputPathType,
    runner: Runner | None = None,
) -> RegResampleOutputs:
    """
    Tool for resampling floating images to the reference image space using different
    transformations.
    
    Author: Marc Modat
    
    URL: http://cmictig.cs.ucl.ac.uk/wiki/index.php/NiftyReg
    
    Args:
        reference_image: Filename of the reference image.
        floating_image: Filename of the floating image.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RegResampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REG_RESAMPLE_METADATA)
    cargs = []
    cargs.append("reg_resample")
    cargs.extend([
        "-ref",
        execution.input_file(reference_image)
    ])
    cargs.extend([
        "-flo",
        execution.input_file(floating_image)
    ])
    cargs.append("[TRANSFORMATION_OPTION]")
    cargs.append("[OUTPUT_OPTIONS]")
    cargs.append("[INTERPOLATION_OPTIONS]")
    ret = RegResampleOutputs(
        root=execution.output_file("."),
        output_resampled_image=execution.output_file("[RESAMPLED_IMAGE]"),
        output_resampled_blank=execution.output_file("[RESAMPLED_BLANK]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REG_RESAMPLE_METADATA",
    "RegResampleOutputs",
    "reg_resample",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

METRIC_REGRESSION_METADATA = Metadata(
    id="5295042a0973d8e0d26bd6976ece94daeb907e50.boutiques",
    name="metric-regression",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class MetricRegressionRemove:
    """
    specify a metric to regress out.
    """
    metric: InputPathType
    """the metric file to use"""
    opt_remove_column_column: str | None = None
    """select a column to use, rather than all: the column number or name"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-remove")
        cargs.append(execution.input_file(self.metric))
        if self.opt_remove_column_column is not None:
            cargs.extend([
                "-remove-column",
                self.opt_remove_column_column
            ])
        return cargs


@dataclasses.dataclass
class MetricRegressionKeep:
    """
    specify a metric to include in regression, but not remove.
    """
    metric: InputPathType
    """the metric file to use"""
    opt_keep_column_column: str | None = None
    """select a column to use, rather than all: the column number or name"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-keep")
        cargs.append(execution.input_file(self.metric))
        if self.opt_keep_column_column is not None:
            cargs.extend([
                "-keep-column",
                self.opt_keep_column_column
            ])
        return cargs


class MetricRegressionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `metric_regression(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def metric_regression(
    metric_in: InputPathType,
    metric_out: str,
    opt_roi_roi_metric: InputPathType | None = None,
    opt_column_column: str | None = None,
    remove: list[MetricRegressionRemove] | None = None,
    keep: list[MetricRegressionKeep] | None = None,
    runner: Runner | None = None,
) -> MetricRegressionOutputs:
    """
    Regress spatial map out of a metric file.
    
    For each regressor, its mean across the surface is subtracted from its data.
    Each input map is then regressed against these, and a constant term. The
    resulting regressed slopes of all regressors specified with -remove are
    multiplied with their respective regressor maps, and these are subtracted
    from the input map.
    
    Author: Washington University School of Medicin
    
    Args:
        metric_in: the metric to regress from.
        metric_out: the output metric.
        opt_roi_roi_metric: only regress inside an roi: the area to use for\
            regression, as a metric.
        opt_column_column: select a single column to regress from: the column\
            number or name.
        remove: specify a metric to regress out.
        keep: specify a metric to include in regression, but not remove.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricRegressionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_REGRESSION_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-regression")
    cargs.append(execution.input_file(metric_in))
    cargs.append(metric_out)
    if opt_roi_roi_metric is not None:
        cargs.extend([
            "-roi",
            execution.input_file(opt_roi_roi_metric)
        ])
    if opt_column_column is not None:
        cargs.extend([
            "-column",
            opt_column_column
        ])
    if remove is not None:
        cargs.extend([a for c in [s.run(execution) for s in remove] for a in c])
    if keep is not None:
        cargs.extend([a for c in [s.run(execution) for s in keep] for a in c])
    ret = MetricRegressionOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(metric_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "METRIC_REGRESSION_METADATA",
    "MetricRegressionKeep",
    "MetricRegressionOutputs",
    "MetricRegressionRemove",
    "metric_regression",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MASKFILTER_METADATA = Metadata(
    id="64d09e2402719ae6eb1c2a4b1802b4a54c209de9.boutiques",
    name="maskfilter",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class MaskfilterConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class MaskfilterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `maskfilter(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """the output image."""


def maskfilter(
    input_: InputPathType,
    filter_: str,
    output: str,
    scale: int | None = None,
    axes: list[int] | None = None,
    largest: bool = False,
    connectivity: bool = False,
    npass: int | None = None,
    extent: list[int] | None = None,
    strides: str | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[MaskfilterConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MaskfilterOutputs:
    """
    Perform filtering operations on 3D / 4D mask images.
    
    The available filters are: clean, connect, dilate, erode, median.
    
    Each filter has its own unique set of optional parameters.
    
    References:
    
    .
    
    Author: Robert E. Smith (robert.smith@florey.edu.au), David Raffelt
    (david.raffelt@florey.edu.au), Thijs Dhollander (thijs.dhollander@gmail.com)
    and J-Donald Tournier (jdtournier@gmail.com)
    
    URL:
    https://mrtrix.readthedocs.io/en/latest/reference/commands/maskfilter.html
    
    Args:
        input_: the input image.
        filter_: the type of filter to be applied (clean, connect, dilate,\
            erode, median).
        output: the output image.
        scale: the maximum scale used to cut bridges. A certain maximum scale\
            cuts bridges up to a width (in voxels) of 2x the provided scale.\
            (Default: 2).
        axes: specify which axes should be included in the connected\
            components. By default only the first 3 axes are included. The axes\
            should be provided as a comma-separated list of values.
        largest: only retain the largest connected component.
        connectivity: use 26-voxel-neighbourhood connectivity (Default: 6).
        npass: the number of times to repeatedly apply the filter.
        extent: specify the extent (width) of kernel size in voxels. This can\
            be specified either as a single value to be used for all axes, or as a\
            comma-separated list of the extent for each axis. The default is 3x3x3.
        strides: specify the strides of the output data in memory; either as a\
            comma-separated list of (signed) integers, or as a template image from\
            which the strides shall be extracted and used. The actual strides\
            produced will depend on whether the output image format can support it.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MaskfilterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MASKFILTER_METADATA)
    cargs = []
    cargs.append("maskfilter")
    if scale is not None:
        cargs.extend([
            "-scale",
            str(scale)
        ])
    if axes is not None:
        cargs.extend([
            "-axes",
            ",".join(map(str, axes))
        ])
    if largest:
        cargs.append("-largest")
    if connectivity:
        cargs.append("-connectivity")
    if npass is not None:
        cargs.extend([
            "-npass",
            str(npass)
        ])
    if extent is not None:
        cargs.extend([
            "-extent",
            ",".join(map(str, extent))
        ])
    if strides is not None:
        cargs.extend([
            "-strides",
            strides
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(input_))
    cargs.append(filter_)
    cargs.append(output)
    ret = MaskfilterOutputs(
        root=execution.output_file("."),
        output=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MASKFILTER_METADATA",
    "MaskfilterConfig",
    "MaskfilterOutputs",
    "maskfilter",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REG_F3D_METADATA = Metadata(
    id="2bb4b67c73d488ef6c20b58357b368c5399e015c.boutiques",
    name="reg_f3d",
    package="niftyreg",
    container_image_tag="vnmd/niftyreg_1.4.0:20220819",
)


class RegF3dOutputs(typing.NamedTuple):
    """
    Output object returned when calling `reg_f3d(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_cpp_file: OutputPathType
    """File containing the output control point grid"""
    output_resampled_image_file: OutputPathType
    """File containing the resampled image"""


def reg_f3d(
    reference_image: InputPathType,
    floating_image: InputPathType,
    runner: Runner | None = None,
) -> RegF3dOutputs:
    """
    Fast Free-Form Deformation algorithm for non-rigid registration based on
    Rueckert's 99 TMI work.
    
    Author: Marc Modat
    
    URL: http://cmictig.cs.ucl.ac.uk/wiki/index.php/NiftyReg
    
    Args:
        reference_image: Filename of the reference image.
        floating_image: Filename of the floating image.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RegF3dOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REG_F3D_METADATA)
    cargs = []
    cargs.append("reg_f3d")
    cargs.append("-ref")
    cargs.extend([
        "-ref",
        execution.input_file(reference_image)
    ])
    cargs.append("-flo")
    cargs.extend([
        "-flo",
        execution.input_file(floating_image)
    ])
    cargs.append("[OPTIONS]")
    ret = RegF3dOutputs(
        root=execution.output_file("."),
        output_cpp_file=execution.output_file("[OUTPUT_CPP]"),
        output_resampled_image_file=execution.output_file("[OUTPUT_RESAMPLED_IMAGE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REG_F3D_METADATA",
    "RegF3dOutputs",
    "reg_f3d",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_MASK_TO_ASCII_METADATA = Metadata(
    id="63ff90109b39c45888c83d4ff4ec5e6513c745f2.boutiques",
    name="3dMaskToASCII",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dMaskToAsciiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_mask_to_ascii(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outputfile: OutputPathType
    """Output file where ASCII string mask or binary mask will be written."""


def v_3d_mask_to_ascii(
    dataset: InputPathType,
    tobin_flag: bool = False,
    runner: Runner | None = None,
) -> V3dMaskToAsciiOutputs:
    """
    Converts a byte-valued 0/1 dataset into an ASCII string, or vice versa.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dMaskToASCII.html
    
    Args:
        dataset: Input dataset (e.g. mask.nii.gz).
        tobin_flag: Read ASCII mask, expand it to byte-valued dataset, and\
            write to stdout.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dMaskToAsciiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_MASK_TO_ASCII_METADATA)
    cargs = []
    cargs.append("3dMaskToASCII")
    if tobin_flag:
        cargs.append("-tobin")
    cargs.append(execution.input_file(dataset))
    cargs.append(">")
    cargs.append("[OUTPUTFILE]")
    ret = V3dMaskToAsciiOutputs(
        root=execution.output_file("."),
        outputfile=execution.output_file("[OUTPUTFILE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dMaskToAsciiOutputs",
    "V_3D_MASK_TO_ASCII_METADATA",
    "v_3d_mask_to_ascii",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GLM_METADATA = Metadata(
    id="cc6bf673df5819d6a362ac568217c6f4e0faf99a.boutiques",
    name="glm",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class GlmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `glm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """Filename for glm parameter estimates (glm betas)."""
    out_cope_outfile: OutputPathType | None
    """Output file name for copes (either as text file or image)."""
    out_data: OutputPathType
    """Output file for preprocessed data."""
    out_f: OutputPathType
    """Output file name for f-value of full model fit."""
    out_file_: OutputPathType
    """File name of glm parameters (if generated)."""
    out_p: OutputPathType
    """Output file name for p-values of z-stats (either as text file or
    image)."""
    out_pf: OutputPathType
    """Output file name for p-value for full model fit."""
    out_res: OutputPathType
    """Output file name for residuals."""
    out_sigsq: OutputPathType
    """Output file name for residual noise variance sigma-square."""
    out_t: OutputPathType
    """Output file name for t-stats (either as text file or image)."""
    out_varcb: OutputPathType
    """Output file name for variance of copes."""
    out_vnscales: OutputPathType
    """Output file name for scaling factors for variance normalisation."""
    out_z: OutputPathType
    """Output file name for copes (either as text file or image)."""


def glm(
    in_file: InputPathType,
    design: InputPathType,
    contrasts: InputPathType | None = None,
    dat_norm: bool = False,
    demean: bool = False,
    des_norm: bool = False,
    dof: int | None = None,
    mask: InputPathType | None = None,
    out_cope: InputPathType | None = None,
    out_data_name: InputPathType | None = None,
    out_f_name: InputPathType | None = None,
    out_p_name: InputPathType | None = None,
    out_pf_name: InputPathType | None = None,
    out_res_name: InputPathType | None = None,
    out_sigsq_name: InputPathType | None = None,
    out_t_name: InputPathType | None = None,
    out_varcb_name: InputPathType | None = None,
    out_vnscales_name: InputPathType | None = None,
    out_z_name: InputPathType | None = None,
    output_type: typing.Literal["NIFTI", "NIFTI_PAIR", "NIFTI_GZ", "NIFTI_PAIR_GZ"] | None = None,
    var_norm: bool = False,
    runner: Runner | None = None,
) -> GlmOutputs:
    """
    FSL GLM.
    
    Author: Nipype (interface)
    
    Args:
        in_file: Input file name (text matrix or 3d/4d image file).
        design: File name of the glm design matrix (text time courses for\
            temporal regression or an image file for spatial regression).
        contrasts: Matrix of t-statics contrasts.
        dat_norm: Switch on normalization of the data time series to unit std\
            deviation.
        demean: Switch on demeaining of design and data.
        des_norm: Switch on normalization of the design matrix columns to unit\
            std deviation.
        dof: Set degrees of freedom explicitly.
        mask: Mask image file name if input is image.
        out_cope: Output file name for cope (either as txt or image.
        out_data_name: Output file name for pre-processed data.
        out_f_name: Output file name for f-value of full model fit.
        out_p_name: Output file name for p-values of z-stats (either as text\
            file or image).
        out_pf_name: Output file name for p-value for full model fit.
        out_res_name: Output file name for residuals.
        out_sigsq_name: Output file name for residual noise variance\
            sigma-square.
        out_t_name: Output file name for t-stats (either as txt or image.
        out_varcb_name: Output file name for variance of copes.
        out_vnscales_name: Output file name for scaling factors for variance\
            normalisation.
        out_z_name: Output file name for z-stats (either as txt or image.
        output_type: 'nifti' or 'nifti_pair' or 'nifti_gz' or 'nifti_pair_gz'.\
            Fsl output type.
        var_norm: Perform melodic variance-normalisation on data.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GlmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GLM_METADATA)
    cargs = []
    cargs.append("GLM")
    cargs.extend([
        "-i",
        execution.input_file(in_file)
    ])
    cargs.extend([
        "-d",
        execution.input_file(design)
    ])
    cargs.append("[OUT_FILE]")
    if contrasts is not None:
        cargs.extend([
            "-c",
            execution.input_file(contrasts)
        ])
    if dat_norm:
        cargs.append("--dat_norm")
    if demean:
        cargs.append("--demean")
    if des_norm:
        cargs.append("--des_norm")
    if dof is not None:
        cargs.append("--dof=" + str(dof))
    if mask is not None:
        cargs.extend([
            "-m",
            execution.input_file(mask)
        ])
    if out_cope is not None:
        cargs.append("--out_cope=" + execution.input_file(out_cope))
    if out_data_name is not None:
        cargs.append("--out_data=" + execution.input_file(out_data_name))
    if out_f_name is not None:
        cargs.append("--out_f=" + execution.input_file(out_f_name))
    if out_p_name is not None:
        cargs.append("--out_p=" + execution.input_file(out_p_name))
    if out_pf_name is not None:
        cargs.append("--out_pf=" + execution.input_file(out_pf_name))
    if out_res_name is not None:
        cargs.append("--out_res=" + execution.input_file(out_res_name))
    if out_sigsq_name is not None:
        cargs.append("--out_sigsq=" + execution.input_file(out_sigsq_name))
    if out_t_name is not None:
        cargs.append("--out_t=" + execution.input_file(out_t_name))
    if out_varcb_name is not None:
        cargs.append("--out_varcb=" + execution.input_file(out_varcb_name))
    if out_vnscales_name is not None:
        cargs.append("--out_vnscales=" + execution.input_file(out_vnscales_name))
    if out_z_name is not None:
        cargs.append("--out_z=" + execution.input_file(out_z_name))
    if output_type is not None:
        cargs.append(output_type)
    if var_norm:
        cargs.append("--vn")
    ret = GlmOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(pathlib.Path(in_file).name + "_glm"),
        out_cope_outfile=execution.output_file(pathlib.Path(out_cope).name) if (out_cope is not None) else None,
        out_data=execution.output_file("out_data"),
        out_f=execution.output_file("out_f"),
        out_file_=execution.output_file("out_file"),
        out_p=execution.output_file("out_p"),
        out_pf=execution.output_file("out_pf"),
        out_res=execution.output_file("out_res"),
        out_sigsq=execution.output_file("out_sigsq"),
        out_t=execution.output_file("out_t"),
        out_varcb=execution.output_file("out_varcb"),
        out_vnscales=execution.output_file("out_vnscales"),
        out_z=execution.output_file("out_z"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GLM_METADATA",
    "GlmOutputs",
    "glm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_AUTO_TCORRELATE_METADATA = Metadata(
    id="b8f27abcfc527642a9e359df2a44024f6a072cb5.boutiques",
    name="3dAutoTcorrelate",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAutoTcorrelateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_auto_tcorrelate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_brick: OutputPathType
    """Main output dataset"""
    output_head: OutputPathType
    """Header information for main output dataset"""
    out1d_file: OutputPathType
    """Output in 1D text format"""


def v_3d_auto_tcorrelate(
    input_dataset: InputPathType,
    runner: Runner | None = None,
) -> V3dAutoTcorrelateOutputs:
    """
    Computes the correlation coefficient between the time series of each pair of
    voxels in the input dataset.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dAutoTcorrelate.html
    
    Args:
        input_dataset: Input dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAutoTcorrelateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_AUTO_TCORRELATE_METADATA)
    cargs = []
    cargs.append("3dAutoTcorrelate")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(input_dataset))
    ret = V3dAutoTcorrelateOutputs(
        root=execution.output_file("."),
        output_brick=execution.output_file("[PREFIX].BRIK"),
        output_head=execution.output_file("[PREFIX].HEAD"),
        out1d_file=execution.output_file("[OUT1D_FILE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAutoTcorrelateOutputs",
    "V_3D_AUTO_TCORRELATE_METADATA",
    "v_3d_auto_tcorrelate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_WARP_METADATA = Metadata(
    id="274373e4ce98f7b2884dd886fb6749d0dbd8381d.boutiques",
    name="3dWarp",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dWarpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_warp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3d_warp(
    dataset: str,
    runner: Runner | None = None,
) -> V3dWarpOutputs:
    """
    Warp (spatially transform) one 3D dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dWarp.html
    
    Args:
        dataset: Input dataset to be warped.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dWarpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_WARP_METADATA)
    cargs = []
    cargs.append("3dWarp")
    cargs.append("[OPTIONS]")
    cargs.append(dataset)
    ret = V3dWarpOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dWarpOutputs",
    "V_3D_WARP_METADATA",
    "v_3d_warp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BAYESIAN_GROUP_ANA_PY_METADATA = Metadata(
    id="a95fea359998077d6c6c35fbe277ea325c90fec4.boutiques",
    name="BayesianGroupAna.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class BayesianGroupAnaPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `bayesian_group_ana_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    summary: OutputPathType
    """Summary of the brmsfit object from R."""
    rhats: OutputPathType
    """Rhats for each effect and x variable combination."""
    intercept_table: OutputPathType
    """Table with the MedianEst, StdDev, 2.50%, 5%, 50%, 95%, and 97.50% of each
    ROI for the Intercept term."""
    x_var_table: OutputPathType
    """The same table as the Intercept but for the specified x variable."""


def bayesian_group_ana_py(
    data_table: InputPathType,
    y_variable: str,
    runner: Runner | None = None,
) -> BayesianGroupAnaPyOutputs:
    """
    This program conducts Bayesian Group Analysis (BGA) on a list of regions of
    interest (ROIs). Compared to the conventional univariate GLM, BGA pools and
    shares the information across the ROIs in a multilevel system.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/BayesianGroupAna.py.html
    
    Args:
        data_table: Input text file containing the data table.
        y_variable: Column name for the y variable.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BayesianGroupAnaPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BAYESIAN_GROUP_ANA_PY_METADATA)
    cargs = []
    cargs.append("/opt/afni/src/../install/BayesianGroupAna.py")
    cargs.append("-dataTable")
    cargs.append(execution.input_file(data_table))
    cargs.append("-y")
    cargs.append(y_variable)
    cargs.append("[OPTIONS]")
    ret = BayesianGroupAnaPyOutputs(
        root=execution.output_file("."),
        summary=execution.output_file("[PREFIX]_summary.txt"),
        rhats=execution.output_file("[PREFIX]_rhats.csv"),
        intercept_table=execution.output_file("[PREFIX]_Intercept_table.csv"),
        x_var_table=execution.output_file("[PREFIX]_table.csv"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BAYESIAN_GROUP_ANA_PY_METADATA",
    "BayesianGroupAnaPyOutputs",
    "bayesian_group_ana_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLSTATS_METADATA = Metadata(
    id="9c9462bb7a07c9f64854acdbb0dfee9186358c56.boutiques",
    name="fslstats",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslstatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslstats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_stats: OutputPathType
    """Statistics output file"""


def fslstats(
    input_file: InputPathType,
    runner: Runner | None = None,
) -> FslstatsOutputs:
    """
    FSL tool for calculating statistics on image data.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils
    
    Args:
        input_file: Input image file (e.g., image.nii.gz).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslstatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLSTATS_METADATA)
    cargs = []
    cargs.append("fslstats")
    cargs.append("[PREOPTIONS]")
    cargs.append(execution.input_file(input_file))
    cargs.append("[OPTIONS]")
    ret = FslstatsOutputs(
        root=execution.output_file("."),
        output_stats=execution.output_file(pathlib.Path(input_file).name + "_stats.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLSTATS_METADATA",
    "FslstatsOutputs",
    "fslstats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DFRACTIONIZE_METADATA = Metadata(
    id="9acaac469a33da6b65a1a097f14422f59f763c36.boutiques",
    name="3dfractionize",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dfractionizeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dfractionize(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType | None
    """Output dataset with the specified prefix."""


def v_3dfractionize(
    template: InputPathType,
    input_: InputPathType,
    prefix: str | None = None,
    clip: float | None = None,
    warp: InputPathType | None = None,
    preserve: bool = False,
    vote: bool = False,
    runner: Runner | None = None,
) -> V3dfractionizeOutputs:
    """
    For each voxel in the output dataset, computes the fraction of it that is
    occupied by nonzero voxels from the input.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dfractionize.html
    
    Args:
        template: Use dataset as a template for the output. The output dataset\
            will be on the same grid as this dataset.
        input_: Use dataset for the input. Only the sub-brick #0 of the input\
            is used.
        prefix: Prefix for the output dataset.
        clip: Clip off voxels that are less than the specified occupancy\
            fraction.
        warp: Dataset that provides a transformation (warp) from +orig\
            coordinates to the coordinates of the input dataset.
        preserve: Preserve the nonzero values of input voxels in the output\
            dataset rather than creating a fractional mask.
        vote: Vote for which input value to preserve when using the preserve\
            flag.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dfractionizeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DFRACTIONIZE_METADATA)
    cargs = []
    cargs.append("3dfractionize")
    cargs.extend([
        "-template",
        execution.input_file(template)
    ])
    cargs.extend([
        "-input",
        execution.input_file(input_)
    ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if clip is not None:
        cargs.extend([
            "-clip",
            str(clip)
        ])
    if warp is not None:
        cargs.extend([
            "-warp",
            execution.input_file(warp)
        ])
    if preserve:
        cargs.append("-preserve")
    if vote:
        cargs.append("-vote")
    ret = V3dfractionizeOutputs(
        root=execution.output_file("."),
        output=execution.output_file(prefix) if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dfractionizeOutputs",
    "V_3DFRACTIONIZE_METADATA",
    "v_3dfractionize",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FABBER_DWI_METADATA = Metadata(
    id="2ab697cea205122397d315705e8906f76b67636d.boutiques",
    name="fabber_dwi",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FabberDwiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fabber_dwi(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType
    """All outputs will be stored in the specified output directory"""


def fabber_dwi(
    runner: Runner | None = None,
) -> FabberDwiOutputs:
    """
    Fabber diffusion-weighted imaging tool for model-based analysis using forward
    models and different inference methods.
    
    Author: Release Team
    
    URL: https://www.fmrib.ox.ac.uk/fabber_dwi
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FabberDwiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FABBER_DWI_METADATA)
    cargs = []
    cargs.append("fabber")
    cargs.append("[PARAMS]")
    ret = FabberDwiOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file("[OUTPUT_DIR]/*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FABBER_DWI_METADATA",
    "FabberDwiOutputs",
    "fabber_dwi",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DEVAL_METADATA = Metadata(
    id="2ed76551181b3017cc88ad182afeaee3af0db125.boutiques",
    name="1deval",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1devalOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1deval(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_1_d: OutputPathType
    """Output of evaluated expression."""


def v_1deval(
    expression: str,
    del_: float | None = None,
    start: float | None = None,
    num: float | None = None,
    index: InputPathType | None = None,
    v_1_d: bool = False,
    symbols: list[InputPathType] | None = None,
    runner: Runner | None = None,
) -> V1devalOutputs:
    """
    Evaluates an expression that may include columns of data from one or more text
    files and writes the result to stdout.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/1deval.html
    
    Args:
        expression: Expression to evaluate.
        del_: Use 'd' as the step for a single undetermined variable in the\
            expression.
        start: Start at value 's' for a single undetermined variable in the\
            expression.
        num: Evaluate the expression 'n' times.
        index: Read index column from file i.1D and write it out as 1st column\
            of output.
        v_1_d: Write output in the form of a single '1D:' string suitable for\
            input on the command line of another program.
        symbols: Read time series file and assign it to the symbol 'a'. Letters\
            'a' to 'z' may be used as symbols.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1devalOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DEVAL_METADATA)
    cargs = []
    cargs.append("1deval")
    if del_ is not None:
        cargs.extend([
            "-del",
            str(del_)
        ])
    if start is not None:
        cargs.extend([
            "-start",
            str(start)
        ])
    if num is not None:
        cargs.extend([
            "-num",
            str(num)
        ])
    if index is not None:
        cargs.extend([
            "-index",
            execution.input_file(index)
        ])
    if v_1_d:
        cargs.append("-1D:")
    if symbols is not None:
        cargs.extend([
            "-a",
            *[execution.input_file(f) for f in symbols]
        ])
    cargs.append("-expr")
    cargs.extend([
        "-expr",
        expression
    ])
    ret = V1devalOutputs(
        root=execution.output_file("."),
        output_1_d=execution.output_file("output.1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1devalOutputs",
    "V_1DEVAL_METADATA",
    "v_1deval",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMLN_METADATA = Metadata(
    id="595162825bdbaad5d60b6891e218c10788288793.boutiques",
    name="imln",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class ImlnOutputs(typing.NamedTuple):
    """
    Output object returned when calling `imln(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_link: OutputPathType
    """The created link to the input file"""


def imln(
    input_file: InputPathType,
    link_name: str,
    runner: Runner | None = None,
) -> ImlnOutputs:
    """
    Creates a link (called file2) to file1.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    Args:
        input_file: The source file (file1) to create a link to.
        link_name: The name for the link (file2).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ImlnOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMLN_METADATA)
    cargs = []
    cargs.append("/usr/local/fsl/bin/imln")
    cargs.append(execution.input_file(input_file))
    cargs.append(link_name)
    ret = ImlnOutputs(
        root=execution.output_file("."),
        output_link=execution.output_file(link_name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMLN_METADATA",
    "ImlnOutputs",
    "imln",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PLUGOUT_TT_METADATA = Metadata(
    id="45542c1e4d6e42e4f524aacafcd6ff7e1bcf91c4.boutiques",
    name="plugout_tt",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class PlugoutTtOutputs(typing.NamedTuple):
    """
    Output object returned when calling `plugout_tt(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def plugout_tt(
    host: str | None = None,
    ijk_option: bool = False,
    verbose: bool = False,
    port: float | None = None,
    name: str | None = None,
    port_offset: float | None = None,
    port_offset_quiet: float | None = None,
    port_bloc: float | None = None,
    max_port_bloc: bool = False,
    max_port_bloc_quiet: bool = False,
    num_assigned_ports: bool = False,
    num_assigned_ports_quiet: bool = False,
    runner: Runner | None = None,
) -> PlugoutTtOutputs:
    """
    This program connects to AFNI and receives notification whenever the user
    changes Talairach coordinates.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/plugout_tt.html
    
    Args:
        host: Name of the host computer to connect to AFNI on. The default is\
            to connect on the current host using shared memory.
        ijk_option: Get voxel indices from AFNI instead of Talairach\
            coordinates.
        verbose: Enable verbose mode (prints lots of diagnostic messages).
        port: TCP/IP port number to use. The default is 8001.
        name: String to use as the name that AFNI assigns to this plugout. The\
            default is something silly.
        port_offset: Provide a port offset to allow multiple instances of\
            communicating programs to operate on the same computer. Use an integer\
            in the inclusive range [1025 to 65500].
        port_offset_quiet: Provide a port offset to allow multiple instances of\
            communicating programs to operate on the same computer with quiet\
            output in case of issues. Use an integer in the inclusive range [1025\
            to 65500].
        port_bloc: Provide a port offset bloc for easier configuration of\
            multiple instances. PORT_OFFSET_BLOC is an integer between 0 and\
            MAX_BLOC (around 4000).
        max_port_bloc: Print the current value of MAX_BLOC and exit. Stay under\
            2000 for safety.
        max_port_bloc_quiet: Print the current value of MAX_BLOC quietly and\
            exit.
        num_assigned_ports: Print the number of assigned ports used by AFNI,\
            then quit.
        num_assigned_ports_quiet: Print the number of assigned ports used by\
            AFNI quietly, then quit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PlugoutTtOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PLUGOUT_TT_METADATA)
    cargs = []
    cargs.append("plugout_tt")
    if host is not None:
        cargs.extend([
            "-host",
            host
        ])
    if ijk_option:
        cargs.append("-ijk")
    if verbose:
        cargs.append("-v")
    if port is not None:
        cargs.extend([
            "-port",
            str(port)
        ])
    if name is not None:
        cargs.extend([
            "-name",
            name
        ])
    if port_offset is not None:
        cargs.extend([
            "-np",
            str(port_offset)
        ])
    if port_offset_quiet is not None:
        cargs.extend([
            "-npq",
            str(port_offset_quiet)
        ])
    if port_bloc is not None:
        cargs.extend([
            "-npb",
            str(port_bloc)
        ])
    if max_port_bloc:
        cargs.append("-max_port_bloc")
    if max_port_bloc_quiet:
        cargs.append("-max_port_bloc_quiet")
    if num_assigned_ports:
        cargs.append("-num_assigned_ports")
    if num_assigned_ports_quiet:
        cargs.append("-num_assigned_ports_quiet")
    ret = PlugoutTtOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PLUGOUT_TT_METADATA",
    "PlugoutTtOutputs",
    "plugout_tt",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EXAMINE_XMAT_METADATA = Metadata(
    id="eb70a859747a89594f1ce12cba7e48ea86cfea01.boutiques",
    name="ExamineXmat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ExamineXmatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `examine_xmat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    plot_image: OutputPathType | None
    """Output plot image"""
    plot_image_png: OutputPathType | None
    """Output plot image"""
    plot_image_pdf: OutputPathType | None
    """Output plot image"""
    cor_image: OutputPathType | None
    """Output cor image"""
    plot_image_prefix: OutputPathType | None
    """Output plot image"""


def examine_xmat(
    input_file: InputPathType | None = None,
    interactive: bool = False,
    prefix: str | None = None,
    cprefix: str | None = None,
    pprefix: str | None = None,
    select_: str | None = None,
    msg_trace: bool = False,
    verbosity: float | None = None,
    runner: Runner | None = None,
) -> ExamineXmatOutputs:
    """
    A program for examining the design matrix generated by 3dDeconvolve.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/ExamineXmat.html
    
    Args:
        input_file: xmat file to plot.
        interactive: Run ExamineXmat in interactive mode. This is the default\
            if -prefix is not given. If -interactive is used with -prefix, the last\
            plot you see is the plot saved to file.
        prefix: Prefix of plot image and cor image.
        cprefix: Prefix of cor image only.
        pprefix: Prefix of plot image only.
        select_: What to plot. Selection strings to specify regressors.
        msg_trace: Output trace information along with errors and notices.
        verbosity: Verbosity level. 0 for quiet, 1 or more for talkative.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ExamineXmatOutputs`).
    """
    if verbosity is not None and not (0 <= verbosity): 
        raise ValueError(f"'verbosity' must be greater than 0 <= x but was {verbosity}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(EXAMINE_XMAT_METADATA)
    cargs = []
    cargs.append("ExamineXmat")
    if input_file is not None:
        cargs.extend([
            "-input",
            execution.input_file(input_file)
        ])
    if interactive:
        cargs.append("-interactive")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if cprefix is not None:
        cargs.extend([
            "-cprefix",
            cprefix
        ])
    if pprefix is not None:
        cargs.extend([
            "-pprefix",
            pprefix
        ])
    if select_ is not None:
        cargs.extend([
            "-select",
            select_
        ])
    if msg_trace:
        cargs.append("-msg.trace")
    if verbosity is not None:
        cargs.extend([
            "-verb",
            str(verbosity)
        ])
    ret = ExamineXmatOutputs(
        root=execution.output_file("."),
        plot_image=execution.output_file(prefix + ".jpg") if (prefix is not None) else None,
        plot_image_png=execution.output_file(prefix + ".png") if (prefix is not None) else None,
        plot_image_pdf=execution.output_file(prefix + ".pdf") if (prefix is not None) else None,
        cor_image=execution.output_file(cprefix + ".jpg") if (cprefix is not None) else None,
        plot_image_prefix=execution.output_file(pprefix + ".jpg") if (pprefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EXAMINE_XMAT_METADATA",
    "ExamineXmatOutputs",
    "examine_xmat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DINFO_METADATA = Metadata(
    id="7079ec8db29fc5abd9efaff614f2daa00228ff5e.boutiques",
    name="3dinfo",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dinfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dinfo(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3dinfo(
    runner: Runner | None = None,
) -> V3dinfoOutputs:
    """
    Prints out sort-of-useful information from a 3D dataset's header.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dinfo.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dinfoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DINFO_METADATA)
    cargs = []
    cargs.append("3dinfo")
    cargs.append("[OPTIONS]")
    cargs.append("DATASET")
    cargs.append("[DATASET...]")
    ret = V3dinfoOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dinfoOutputs",
    "V_3DINFO_METADATA",
    "v_3dinfo",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMMV_METADATA = Metadata(
    id="36c60ed06eb8cb00f4d31f9c69cf56412092ddb0.boutiques",
    name="immv",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class ImmvOutputs(typing.NamedTuple):
    """
    Output object returned when calling `immv(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def immv(
    source_files: list[InputPathType],
    destination: str,
    runner: Runner | None = None,
) -> ImmvOutputs:
    """
    Moves images from one file or directory to another.
    
    Author: Unknown
    
    Args:
        source_files: Source files to be moved. Recognized file extensions:\
            .nii.gz, .nii, .img, .hdr, .img.gz, .hdr.gz.
        destination: Destination file or directory.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ImmvOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMMV_METADATA)
    cargs = []
    cargs.append("immv")
    cargs.extend([execution.input_file(f) for f in source_files])
    cargs.append(destination)
    ret = ImmvOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMMV_METADATA",
    "ImmvOutputs",
    "immv",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_PAIRWISE_CORRELATION_METADATA = Metadata(
    id="df423945fb398876763bf3f54f287e041e7abe8c.boutiques",
    name="cifti-pairwise-correlation",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class CiftiPairwiseCorrelationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_pairwise_correlation(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """output cifti file"""


def cifti_pairwise_correlation(
    cifti_a: InputPathType,
    cifti_b: InputPathType,
    cifti_out: str,
    opt_fisher_z: bool = False,
    opt_override_mapping_check: bool = False,
    runner: Runner | None = None,
) -> CiftiPairwiseCorrelationOutputs:
    """
    Correlate paired rows between two cifti files.
    
    For each row in <cifti-a>, correlate it with the same row in <cifti-b>, and
    put the result in the same row of <cifti-out>, which has only one column.
    
    Author: Washington University School of Medicin
    
    Args:
        cifti_a: first input cifti file.
        cifti_b: second input cifti file.
        cifti_out: output cifti file.
        opt_fisher_z: apply fisher small z transform (ie, artanh) to\
            correlation.
        opt_override_mapping_check: don't check the mappings for compatibility,\
            only check length.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiPairwiseCorrelationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_PAIRWISE_CORRELATION_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-pairwise-correlation")
    cargs.append(execution.input_file(cifti_a))
    cargs.append(execution.input_file(cifti_b))
    cargs.append(cifti_out)
    if opt_fisher_z:
        cargs.append("-fisher-z")
    if opt_override_mapping_check:
        cargs.append("-override-mapping-check")
    ret = CiftiPairwiseCorrelationOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_PAIRWISE_CORRELATION_METADATA",
    "CiftiPairwiseCorrelationOutputs",
    "cifti_pairwise_correlation",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DJUNCT_SSW_INTERMED_EDGE_IMGS_METADATA = Metadata(
    id="d2d8a138e3c9ac7e43de45867b6cfda67508d0da.boutiques",
    name="@djunct_ssw_intermed_edge_imgs",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDjunctSswIntermedEdgeImgsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__djunct_ssw_intermed_edge_imgs(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__djunct_ssw_intermed_edge_imgs(
    prefix: str,
    ulay: InputPathType,
    olay: InputPathType,
    box_focus_slices: str | None = None,
    montgap: str | None = None,
    cbar: str | None = None,
    ulay_range: str | None = None,
    montx: str | None = None,
    monty: str | None = None,
    help_view: bool = False,
    help_: bool = False,
    version: bool = False,
    no_clean: bool = False,
    runner: Runner | None = None,
) -> VDjunctSswIntermedEdgeImgsOutputs:
    """
    Helper script to generate intermediate edge images for SSW-related processing.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@djunct_ssw_intermed_edge_imgs.html
    
    Args:
        prefix: Prefix for generated output files.
        ulay: Underlay dataset.
        olay: Overlay dataset.
        box_focus_slices: Slices of interest for focus box.
        montgap: Gap between montage slices.
        cbar: Color bar specification for AFNI.
        ulay_range: Range for underlay data mapping.
        montx: Number of slices along x dimension in montage.
        monty: Number of slices along y dimension in montage.
        help_view: View help file in viewer.
        help_: Displays help information.
        version: Displays version information.
        no_clean: Don't clean up intermediate files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDjunctSswIntermedEdgeImgsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DJUNCT_SSW_INTERMED_EDGE_IMGS_METADATA)
    cargs = []
    cargs.append("@djunct_ssw_intermed_edge_imgs")
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.extend([
        "-ulay",
        execution.input_file(ulay)
    ])
    cargs.extend([
        "-olay",
        execution.input_file(olay)
    ])
    if box_focus_slices is not None:
        cargs.extend([
            "-box_focus_slices",
            box_focus_slices
        ])
    if montgap is not None:
        cargs.extend([
            "-montgap",
            montgap
        ])
    if cbar is not None:
        cargs.extend([
            "-cbar",
            cbar
        ])
    if ulay_range is not None:
        cargs.extend([
            "-ulay_range",
            ulay_range
        ])
    if montx is not None:
        cargs.extend([
            "-montx",
            montx
        ])
    if monty is not None:
        cargs.extend([
            "-monty",
            monty
        ])
    if help_view:
        cargs.append("-hview")
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-ver")
    if no_clean:
        cargs.append("-no_clean")
    ret = VDjunctSswIntermedEdgeImgsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDjunctSswIntermedEdgeImgsOutputs",
    "V__DJUNCT_SSW_INTERMED_EDGE_IMGS_METADATA",
    "v__djunct_ssw_intermed_edge_imgs",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BEDPOSTX_SINGLE_SLICE_SH_METADATA = Metadata(
    id="c5da5b3d8c7782f095a232569e1a4d3af1ffde90.boutiques",
    name="bedpostx_single_slice.sh",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class BedpostxSingleSliceShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `bedpostx_single_slice_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def bedpostx_single_slice_sh(
    input_number: str,
    output_length: float,
    runner: Runner | None = None,
) -> BedpostxSingleSliceShOutputs:
    """
    Add leading zeros to a number up to the specified length.
    
    Args:
        input_number: Input number to pad.
        output_length: Desired length of output with leading zeros.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BedpostxSingleSliceShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BEDPOSTX_SINGLE_SLICE_SH_METADATA)
    cargs = []
    cargs.append("zeropad")
    cargs.append(input_number)
    cargs.append(str(output_length))
    ret = BedpostxSingleSliceShOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BEDPOSTX_SINGLE_SLICE_SH_METADATA",
    "BedpostxSingleSliceShOutputs",
    "bedpostx_single_slice_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__EXAMINE_GEN_FEAT_DISTS_METADATA = Metadata(
    id="dd1cfdf548e36bdd39bd8d7122ae39677180eed3.boutiques",
    name="@ExamineGenFeatDists",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VExamineGenFeatDistsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__examine_gen_feat_dists(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__examine_gen_feat_dists(
    features_dir: str,
    wildcards: list[str] | None = None,
    output_suffix: str | None = None,
    exclude_features: list[str] | None = None,
    exclude_classes: list[str] | None = None,
    output_dir: str | None = None,
    panels_horizontal: float | None = None,
    echo: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> VExamineGenFeatDistsOutputs:
    """
    Examine histograms produced by 3dGenFeatDists.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@ExamineGenFeatDists.html
    
    Args:
        features_dir: Output directory of 3dGenFeatDists.
        wildcards: Wildcards used to select feature histograms under the\
            directory.
        output_suffix: Output suffix, added to output images. Default is\
            'nosuff'.
        exclude_features: Exclude following features. String matching is\
            partial.
        exclude_classes: Exclude following classes. String matching is partial.
        output_dir: Output directory, default is the same as -fdir.
        panels_horizontal: Set number of panels along the horizontal direction.
        echo: Set echo.
        help_: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VExamineGenFeatDistsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__EXAMINE_GEN_FEAT_DISTS_METADATA)
    cargs = []
    cargs.append("@ExamineGenFeatDists")
    cargs.append("-fdir")
    cargs.extend([
        "-fdir",
        features_dir
    ])
    cargs.append("-fwild")
    if wildcards is not None:
        cargs.extend([
            "-fwild",
            *wildcards
        ])
    cargs.append("-suffix")
    if output_suffix is not None:
        cargs.extend([
            "-suffix",
            output_suffix
        ])
    cargs.append("-exfeat")
    if exclude_features is not None:
        cargs.extend([
            "-exfeat",
            *exclude_features
        ])
    cargs.append("-exclass")
    if exclude_classes is not None:
        cargs.extend([
            "-exclass",
            *exclude_classes
        ])
    cargs.append("-odir")
    if output_dir is not None:
        cargs.extend([
            "-odir",
            output_dir
        ])
    cargs.append("-nx")
    if panels_horizontal is not None:
        cargs.extend([
            "-nx",
            str(panels_horizontal)
        ])
    cargs.append("-echo")
    if echo:
        cargs.append("-echo")
    cargs.append("-help")
    if help_:
        cargs.append("-help")
    ret = VExamineGenFeatDistsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VExamineGenFeatDistsOutputs",
    "V__EXAMINE_GEN_FEAT_DISTS_METADATA",
    "v__examine_gen_feat_dists",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SH2RESPONSE_METADATA = Metadata(
    id="2ac3ba8ab50d4cf9227f875454b7446510342d3c.boutiques",
    name="sh2response",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class Sh2responseConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class Sh2responseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `sh2response(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    response: OutputPathType
    """the output axially-symmetric spherical harmonic coefficients"""
    dump: OutputPathType | None
    """dump the m=0 SH coefficients from all voxels in the mask to the output
    file, rather than their mean """


def sh2response(
    sh: InputPathType,
    mask: InputPathType,
    directions: InputPathType,
    response: str,
    lmax: int | None = None,
    dump: str | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[Sh2responseConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> Sh2responseOutputs:
    """
    Generate an appropriate response function from the image data for spherical
    deconvolution.
    
    The spherical harmonic coefficients are stored according the conventions
    described the main documentation, which can be found at the following link:
    https://mrtrix.readthedocs.io/en/3.0.4/concepts/spherical_harmonics.html
    
    References:
    
    .
    
    Author: J-Donald Tournier (jdtournier@gmail.com)
    
    URL:
    https://mrtrix.readthedocs.io/en/latest/reference/commands/sh2response.html
    
    Args:
        sh: the spherical harmonic decomposition of the diffusion-weighted\
            images.
        mask: the mask containing the voxels from which to estimate the\
            response function.
        directions: a 4D image containing the direction vectors along which to\
            estimate the response function.
        response: the output axially-symmetric spherical harmonic coefficients.
        lmax: specify the maximum harmonic degree of the response function to\
            estimate.
        dump: dump the m=0 SH coefficients from all voxels in the mask to the\
            output file, rather than their mean.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Sh2responseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SH2RESPONSE_METADATA)
    cargs = []
    cargs.append("sh2response")
    if lmax is not None:
        cargs.extend([
            "-lmax",
            str(lmax)
        ])
    if dump is not None:
        cargs.extend([
            "-dump",
            dump
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(sh))
    cargs.append(execution.input_file(mask))
    cargs.append(execution.input_file(directions))
    cargs.append(response)
    ret = Sh2responseOutputs(
        root=execution.output_file("."),
        response=execution.output_file(response),
        dump=execution.output_file(dump) if (dump is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SH2RESPONSE_METADATA",
    "Sh2responseConfig",
    "Sh2responseOutputs",
    "sh2response",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FABBER_T1_METADATA = Metadata(
    id="ffe620ce939d326df00477689e030d74be31e73f.boutiques",
    name="fabber_t1",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FabberT1Outputs(typing.NamedTuple):
    """
    Output object returned when calling `fabber_t1(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    param_names: OutputPathType
    """File containing the names of the model parameters"""
    model_fit: OutputPathType
    """Output the model prediction as a 4D volume"""
    residuals: OutputPathType
    """Output the residuals (difference between the data and the model
    prediction)"""
    model_extras: OutputPathType
    """Output any additional model-specific timeseries data"""
    mvn_distributions: OutputPathType
    """Output the final MVN distributions"""
    param_means: OutputPathType
    """Output the parameter means"""
    param_stds: OutputPathType
    """Output the parameter standard deviations"""
    param_vars: OutputPathType
    """Output the parameter variances"""
    param_zstats: OutputPathType
    """Output the parameter Z-stats"""
    noise_means: OutputPathType
    """Output the noise means"""
    noise_stds: OutputPathType
    """Output the noise standard deviations"""
    free_energy: OutputPathType
    """Output the free energy"""


def fabber_t1(
    output: str,
    method: str,
    model: str,
    data_mult: list[InputPathType] | None = None,
    data_order: str | None = "interleave",
    mask: InputPathType | None = None,
    supp_data: InputPathType | None = None,
    overwrite: bool = False,
    link_to_latest: bool = False,
    simple_output: bool = False,
    load_models: InputPathType | None = None,
    evaluate: str | None = None,
    evaluate_params: str | None = None,
    evaluate_nt: float | None = None,
    dump_param_names: bool = False,
    save_model_fit: bool = False,
    save_residuals: bool = False,
    save_model_extras: bool = False,
    save_mvn: bool = False,
    save_mean: bool = False,
    save_std: bool = False,
    save_var: bool = False,
    save_zstat: bool = False,
    save_noise_mean: bool = False,
    save_noise_std: bool = False,
    save_free_energy: bool = False,
    optfile: InputPathType | None = None,
    debug: bool = False,
    runner: Runner | None = None,
) -> FabberT1Outputs:
    """
    Fabber is a tool for performing model-based analysis of fMRI data, using
    advanced Bayesian inference techniques.
    
    Author: FMRIB Analysis Group
    
    Args:
        output: Directory for output files (including logfile).
        method: Inference method to use.
        model: Forward model to use.
        data_mult: Specify multiple data files for n=1, 2, 3...
        data_order: How multiple data files are handled: concatenate or\
            interleave.
        mask: Mask file. Inference will only be performed where mask value > 0.
        supp_data: Supplemental timeseries data, required for some models.
        overwrite: Overwrite existing output. If not set, new output\
            directories will be created by appending '+' to the directory name.
        link_to_latest: Try to create a link to the most recent output\
            directory with the prefix _latest.
        simple_output: Simple output format: progress as percentage.
        load_models: Load models dynamically from the specified filename, which\
            should be a DLL/shared library.
        evaluate: Evaluate model. Set to name of output required or blank for\
            default output.
        evaluate_params: List of parameter values for evaluation.
        evaluate_nt: Number of time points for evaluation - must be consistent\
            with model options where appropriate.
        dump_param_names: Write the file paramnames.txt containing the names of\
            the model parameters.
        save_model_fit: Output the model prediction as a 4d volume.
        save_residuals: Output the residuals (difference between the data and\
            the model prediction).
        save_model_extras: Output any additional model-specific timeseries data.
        save_mvn: Output the final MVN distributions.
        save_mean: Output the parameter means.
        save_std: Output the parameter standard deviations.
        save_var: Output the parameter variances.
        save_zstat: Output the parameter Zstats.
        save_noise_mean: Output the noise means. The noise distribution\
            inferred is the precision of a Gaussian noise source.
        save_noise_std: Output the noise standard deviations.
        save_free_energy: Output the free energy, if calculated.
        optfile: File containing additional options, one per line, in the same\
            form as specified on the command line.
        debug: Output large amounts of debug information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FabberT1Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FABBER_T1_METADATA)
    cargs = []
    cargs.append("fabber")
    cargs.extend([
        "--output",
        output
    ])
    cargs.extend([
        "--method",
        method
    ])
    cargs.extend([
        "--model",
        model
    ])
    if data_mult is not None:
        cargs.extend([
            "--data<n>",
            *[execution.input_file(f) for f in data_mult]
        ])
    if data_order is not None:
        cargs.extend([
            "--data-order",
            data_order
        ])
    if mask is not None:
        cargs.extend([
            "--mask",
            execution.input_file(mask)
        ])
    cargs.append("[MASKED_TIME_POINTS]")
    if supp_data is not None:
        cargs.extend([
            "--suppdata",
            execution.input_file(supp_data)
        ])
    if overwrite:
        cargs.append("--overwrite")
    if link_to_latest:
        cargs.append("--link-to-latest")
    if simple_output:
        cargs.append("--simple-output")
    if load_models is not None:
        cargs.extend([
            "--loadmodels",
            execution.input_file(load_models)
        ])
    if evaluate is not None:
        cargs.extend([
            "--evaluate",
            evaluate
        ])
    if evaluate_params is not None:
        cargs.extend([
            "--evaluate-params",
            evaluate_params
        ])
    if evaluate_nt is not None:
        cargs.extend([
            "--evaluate-nt",
            str(evaluate_nt)
        ])
    if dump_param_names:
        cargs.append("--dump-param-names")
    if save_model_fit:
        cargs.append("--save-model-fit")
    if save_residuals:
        cargs.append("--save-residuals")
    if save_model_extras:
        cargs.append("--save-model-extras")
    if save_mvn:
        cargs.append("--save-mvn")
    if save_mean:
        cargs.append("--save-mean")
    if save_std:
        cargs.append("--save-std")
    if save_var:
        cargs.append("--save-var")
    if save_zstat:
        cargs.append("--save-zstat")
    if save_noise_mean:
        cargs.append("--save-noise-mean")
    if save_noise_std:
        cargs.append("--save-noise-std")
    if save_free_energy:
        cargs.append("--save-free-energy")
    if optfile is not None:
        cargs.extend([
            "--optfile",
            execution.input_file(optfile)
        ])
    if debug:
        cargs.append("--debug")
    ret = FabberT1Outputs(
        root=execution.output_file("."),
        param_names=execution.output_file(output + "/paramnames.txt"),
        model_fit=execution.output_file(output + "/model_prediction.nii.gz"),
        residuals=execution.output_file(output + "/residuals.nii.gz"),
        model_extras=execution.output_file(output + "/model_extras.nii.gz"),
        mvn_distributions=execution.output_file(output + "/mvn_distributions.nii.gz"),
        param_means=execution.output_file(output + "/param_means.nii.gz"),
        param_stds=execution.output_file(output + "/param_stds.nii.gz"),
        param_vars=execution.output_file(output + "/param_vars.nii.gz"),
        param_zstats=execution.output_file(output + "/param_zstats.nii.gz"),
        noise_means=execution.output_file(output + "/noise_means.nii.gz"),
        noise_stds=execution.output_file(output + "/noise_stds.nii.gz"),
        free_energy=execution.output_file(output + "/free_energy.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FABBER_T1_METADATA",
    "FabberT1Outputs",
    "fabber_t1",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MIDTRANS_METADATA = Metadata(
    id="b39eff2ab1a7b0607739374c3b6c7f807e455f79.boutiques",
    name="midtrans",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class MidtransOutputs(typing.NamedTuple):
    """
    Output object returned when calling `midtrans(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def midtrans(
    transforms: list[InputPathType],
    runner: Runner | None = None,
) -> MidtransOutputs:
    """
    Calculate the midpoint transform from a series of input transforms.
    
    Author: University of Oxford (Mark Jenkinson)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/
    
    Args:
        transforms: List of input transform files (e.g. transform1.mat\
            transform2.mat ... transformN.mat).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MidtransOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MIDTRANS_METADATA)
    cargs = []
    cargs.append("midtrans")
    cargs.append("[OPTIONS]")
    cargs.extend([execution.input_file(f) for f in transforms])
    cargs.append("[TRANSFORM2]")
    cargs.append("...")
    cargs.append("[TRANSFORMN]")
    ret = MidtransOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MIDTRANS_METADATA",
    "MidtransOutputs",
    "midtrans",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DEMO_PROMPT_METADATA = Metadata(
    id="d7d11524aa7bc99fbed5409167986014f1d0c85b.boutiques",
    name="@demo_prompt",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDemoPromptOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__demo_prompt(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    status: OutputPathType
    """Status output: 0 if user presses OK, 1 if user cancels"""


def v__demo_prompt(
    message: str,
    runner: Runner | None = None,
) -> VDemoPromptOutputs:
    """
    Prompts user with a message and waits for acknowledgment.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@demo_prompt.html
    
    Args:
        message: The message to display in the prompt.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDemoPromptOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DEMO_PROMPT_METADATA)
    cargs = []
    cargs.append("@demo_prompt")
    cargs.append(message)
    ret = VDemoPromptOutputs(
        root=execution.output_file("."),
        status=execution.output_file("status"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDemoPromptOutputs",
    "V__DEMO_PROMPT_METADATA",
    "v__demo_prompt",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ANHIST_METADATA = Metadata(
    id="c5a8bc2df4e27276351e63f83dd18e2136b73956.boutiques",
    name="3dAnhist",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAnhistOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_anhist(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_1_d: OutputPathType
    """Dumped histogram data"""
    output_ps: OutputPathType
    """Plot of histogram data"""


def v_3d_anhist(
    dataset: InputPathType,
    quiet: bool = False,
    dump_histogram: bool = False,
    no_scurve: bool = False,
    winsorize: str | None = None,
    top_2peaks: bool = False,
    label: str | None = None,
    filename: str | None = None,
    runner: Runner | None = None,
) -> V3dAnhistOutputs:
    """
    Tool to analyze histogram peaks in a T1-weighted high-res brain image dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dAnhist.html
    
    Args:
        dataset: Input dataset, should be T1-weighted high-res brain image\
            (shorts only).
        quiet: Suppress progress reports.
        dump_histogram: Dump histogram data to Anhist.1D and plot to Anhist.ps.
        no_scurve: Do not fit histogram with curves.
        winsorize: Apply Winsorizing filter prior to histogram scan. Can\
            specify number of times (e.g., -w7).
        top_2peaks: Analyze top 2 peaks only, for overlap, etc.
        label: Use specified label for Anhist.ps plot file instead of the input\
            dataset filename.
        filename: Use specified filename instead of 'Anhist'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAnhistOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ANHIST_METADATA)
    cargs = []
    cargs.append("3dAnhist")
    cargs.append(execution.input_file(dataset))
    if quiet:
        cargs.append("-q")
    if dump_histogram:
        cargs.append("-h")
    if no_scurve:
        cargs.append("-F")
    if winsorize is not None:
        cargs.extend([
            "-w",
            winsorize
        ])
    if top_2peaks:
        cargs.append("-2")
    if label is not None:
        cargs.extend([
            "-label",
            label
        ])
    if filename is not None:
        cargs.extend([
            "-fname",
            filename
        ])
    ret = V3dAnhistOutputs(
        root=execution.output_file("."),
        output_1_d=execution.output_file("Anhist.1D"),
        output_ps=execution.output_file("Anhist.ps"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAnhistOutputs",
    "V_3D_ANHIST_METADATA",
    "v_3d_anhist",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FILMBABESCRIPT_METADATA = Metadata(
    id="9ab884875e83253614c3c611f6bada1f6ecbb988.boutiques",
    name="filmbabescript",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FilmbabescriptOutputs(typing.NamedTuple):
    """
    Output object returned when calling `filmbabescript(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def filmbabescript(
    feat_dir: str,
    flobs_dir: str,
    runner: Runner | None = None,
) -> FilmbabescriptOutputs:
    """
    A tool/script for processing FEAT directories and FLOBs directories.
    
    Author: Author Unknown
    
    URL: URL not provided
    
    Args:
        feat_dir: Input FEAT directory.
        flobs_dir: Input FLOBs directory.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FilmbabescriptOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FILMBABESCRIPT_METADATA)
    cargs = []
    cargs.append("filmbabescript")
    cargs.append(feat_dir)
    cargs.append(flobs_dir)
    ret = FilmbabescriptOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FILMBABESCRIPT_METADATA",
    "FilmbabescriptOutputs",
    "filmbabescript",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_SUB_REPORT_METADATA = Metadata(
    id="ce23ba4c898e3d66ad396a3b3d4a8c8a30299bd7.boutiques",
    name="fsl_sub_report",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslSubReportOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_sub_report(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fsl_sub_report(
    job_id: str,
    subjob_id: str | None = None,
    parseable_flag: bool = False,
    runner: Runner | None = None,
) -> FslSubReportOutputs:
    """
    FSL cluster job reporting tool.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    Args:
        job_id: Report job details for this job ID.
        subjob_id: Report job details for this subjob ID's only.
        parseable_flag: Include all output '|' separated.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslSubReportOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_SUB_REPORT_METADATA)
    cargs = []
    cargs.append("fsl_sub_report")
    cargs.append(job_id)
    cargs.append("[SUBJOB_ID_FLAG]")
    if subjob_id is not None:
        cargs.extend([
            "--subjob_id",
            subjob_id
        ])
    if parseable_flag:
        cargs.append("--parseable")
    ret = FslSubReportOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_SUB_REPORT_METADATA",
    "FslSubReportOutputs",
    "fsl_sub_report",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__R_FUNCLIST_METADATA = Metadata(
    id="9490879edb062904e83247c8917c8d58d72e0fd5.boutiques",
    name="@R_funclist",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VRFunclistOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__r_funclist(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__r_funclist(
    r_files: list[InputPathType] | None = None,
    runner: Runner | None = None,
) -> VRFunclistOutputs:
    """
    A quick list of functions defined in AFNI's .R files.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@R_funclist.html
    
    Args:
        r_files: R file(s) to be processed. If no files are specified, all .R\
            files in afni's bin directory are processed.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VRFunclistOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__R_FUNCLIST_METADATA)
    cargs = []
    cargs.append("@R_funclist")
    if r_files is not None:
        cargs.extend([execution.input_file(f) for f in r_files])
    ret = VRFunclistOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VRFunclistOutputs",
    "V__R_FUNCLIST_METADATA",
    "v__r_funclist",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

B0CALC_METADATA = Metadata(
    id="1372960ea266d118a26cbc4c615737ea241423e2.boutiques",
    name="b0calc",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class B0calcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `b0calc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    b0_output: OutputPathType
    """B0 output volume"""
    b0_output_x: OutputPathType
    """B0 x-component output volume (if --xyz is specified)"""
    b0_output_y: OutputPathType
    """B0 y-component output volume (if --xyz is specified)"""
    b0_output_z: OutputPathType
    """B0 z-component output volume (if --xyz is specified)"""


def b0calc(
    input_file: InputPathType,
    output_file: str,
    zero_order_x: float | None = None,
    zero_order_y: float | None = None,
    zero_order_z: float | None = None,
    b0_x: float | None = None,
    b0_y: float | None = None,
    b0_z: float | None = None,
    delta: float | None = None,
    chi0: float | None = None,
    xyz_flag: bool = False,
    extend_boundary: float | None = None,
    direct_conv: bool = False,
    verbose_flag: bool = False,
    runner: Runner | None = None,
) -> B0calcOutputs:
    """
    B0 field calculation program.
    
    Author: University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FUGUE/Guide#fieldmapcreation
    
    Args:
        input_file: Filename of input image (usually a tissue/air segmentation).
        output_file: Filename of B0 output volume.
        zero_order_x: Value for zeroth-order x-gradient field (per mm);\
            default=0.
        zero_order_y: Value for zeroth-order y-gradient field (per mm);\
            default=0.
        zero_order_z: Value for zeroth-order z-gradient field (per mm);\
            default=0.
        b0_x: Value for zeroth-order B0 field (x-component); default=0.
        b0_y: Value for zeroth-order B0 field (y-component); default=0.
        b0_z: Value for zeroth-order B0 field (z-component); default=1.
        delta: Delta value (chi_tissue - chi_air); default=-9.45e-6.
        chi0: Value for susceptibility of air; default=+4e-7.
        xyz_flag: Calculate and save all 3 field components (i.e. x,y,z).
        extend_boundary: Relative proportion to extend voxels at boundary;\
            default=1.
        direct_conv: Use direct (image space) convolution, not FFT.
        verbose_flag: Switch on diagnostic messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `B0calcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(B0CALC_METADATA)
    cargs = []
    cargs.append("b0calc")
    cargs.append("-i")
    cargs.extend([
        "-i",
        execution.input_file(input_file)
    ])
    cargs.append("-o")
    cargs.extend([
        "-o",
        output_file
    ])
    if zero_order_x is not None:
        cargs.extend([
            "--gx",
            str(zero_order_x)
        ])
    if zero_order_y is not None:
        cargs.extend([
            "--gy",
            str(zero_order_y)
        ])
    if zero_order_z is not None:
        cargs.extend([
            "--gz",
            str(zero_order_z)
        ])
    if b0_x is not None:
        cargs.extend([
            "--b0x",
            str(b0_x)
        ])
    if b0_y is not None:
        cargs.extend([
            "--b0y",
            str(b0_y)
        ])
    if b0_z is not None:
        cargs.extend([
            "--b0",
            str(b0_z)
        ])
    if delta is not None:
        cargs.extend([
            "-d",
            str(delta)
        ])
    if chi0 is not None:
        cargs.extend([
            "--chi0",
            str(chi0)
        ])
    if xyz_flag:
        cargs.append("--xyz")
    if extend_boundary is not None:
        cargs.extend([
            "--extendboundary",
            str(extend_boundary)
        ])
    if direct_conv:
        cargs.append("--directconv")
    if verbose_flag:
        cargs.append("-v")
    ret = B0calcOutputs(
        root=execution.output_file("."),
        b0_output=execution.output_file(output_file),
        b0_output_x=execution.output_file(output_file + "_x"),
        b0_output_y=execution.output_file(output_file + "_y"),
        b0_output_z=execution.output_file(output_file + "_z"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "B0CALC_METADATA",
    "B0calcOutputs",
    "b0calc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FUGUE_METADATA = Metadata(
    id="8bb010f7071a4c177c3c339c359c982de16bdbbe.boutiques",
    name="fugue",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FugueOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fugue(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    fmap_out_file_outfile: OutputPathType | None
    """Fieldmap file."""
    shift_out_file_outfile: OutputPathType | None
    """Voxel shift map file."""
    unwarped_file_outfile: OutputPathType | None
    """Unwarped file."""
    warped_file_outfile: OutputPathType | None
    """Forward warped file."""


def fugue(
    asym_se_time: float | None = None,
    despike_2dfilter: bool = False,
    despike_threshold: float | None = None,
    dwell_time: float | None = None,
    dwell_to_asym_ratio: float | None = None,
    fmap_in_file: InputPathType | None = None,
    fmap_out_file: InputPathType | None = None,
    forward_warping: bool = False,
    fourier_order: int | None = None,
    icorr: bool = False,
    icorr_only: bool = False,
    in_file: InputPathType | None = None,
    mask_file: InputPathType | None = None,
    median_2dfilter: bool = False,
    no_extend: bool = False,
    no_gap_fill: bool = False,
    nokspace: bool = False,
    output_type: typing.Literal["NIFTI", "NIFTI_PAIR", "NIFTI_GZ", "NIFTI_PAIR_GZ"] | None = None,
    pava: bool = False,
    phase_conjugate: bool = False,
    phasemap_in_file: InputPathType | None = None,
    poly_order: int | None = None,
    save_fmap: bool = False,
    save_shift: bool = False,
    save_unmasked_fmap: bool = False,
    save_unmasked_shift: bool = False,
    shift_in_file: InputPathType | None = None,
    shift_out_file: InputPathType | None = None,
    smooth2d: float | None = None,
    smooth3d: float | None = None,
    unwarp_direction: typing.Literal["x", "y", "z", "x-", "y-", "z-"] | None = None,
    unwarped_file: InputPathType | None = None,
    warped_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> FugueOutputs:
    """
    FSL FUGUE set of tools for EPI distortion correction
    `FUGUE is, most generally, a set of tools for EPI distortion correction.
    Distortions may be corrected for 1. improving registration with
    non-distorted images (e.g. structurals), or 2. dealing with motion-dependent
    changes.
    FUGUE is designed to deal only with the first case - improving registration.
    
    Author: Nipype (interface)
    
    URL: http://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FUGUE
    
    Args:
        asym_se_time: Set the fieldmap asymmetric spin echo time (sec).
        despike_2dfilter: Apply a 2d de-spiking filter.
        despike_threshold: Specify the threshold for de-spiking (default=3.0).
        dwell_time: Set the epi dwell time per phase-encode line - same as echo\
            spacing - (sec).
        dwell_to_asym_ratio: Set the dwell to asym time ratio.
        fmap_in_file: Filename for loading fieldmap (rad/s).
        fmap_out_file: Filename for saving fieldmap (rad/s).
        forward_warping: Apply forward warping instead of unwarping.
        fourier_order: Apply fourier (sinusoidal) fitting of order n.
        icorr: Apply intensity correction to unwarping (pixel shift method\
            only).
        icorr_only: Apply intensity correction only.
        in_file: Filename of input volume.
        mask_file: Filename for loading valid mask.
        median_2dfilter: Apply 2d median filtering.
        no_extend: Do not apply rigid-body extrapolation to the fieldmap.
        no_gap_fill: Do not apply gap-filling measure to the fieldmap.
        nokspace: Do not use k-space forward warping.
        output_type: 'nifti' or 'nifti_pair' or 'nifti_gz' or 'nifti_pair_gz'.\
            Fsl output type.
        pava: Apply monotonic enforcement via pava.
        phase_conjugate: Apply phase conjugate method of unwarping.
        phasemap_in_file: Filename for input phase image.
        poly_order: Apply polynomial fitting of order n.
        save_fmap: Write field map volume.
        save_shift: Write pixel shift volume.
        save_unmasked_fmap: Saves the unmasked fieldmap when using --savefmap.
        save_unmasked_shift: Saves the unmasked shiftmap when using\
            --saveshift.
        shift_in_file: Filename for reading pixel shift volume.
        shift_out_file: Filename for saving pixel shift volume.
        smooth2d: Apply 2d gaussian smoothing of sigma n (in mm).
        smooth3d: Apply 3d gaussian smoothing of sigma n (in mm).
        unwarp_direction: 'x' or 'y' or 'z' or 'x-' or 'y-' or 'z-'. Specifies\
            direction of warping (default y).
        unwarped_file: Apply unwarping and save as filename.
        warped_file: Apply forward warping and save as filename.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FugueOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FUGUE_METADATA)
    cargs = []
    cargs.append("FUGUE")
    if asym_se_time is not None:
        cargs.append("--asym=" + str(asym_se_time))
    if despike_2dfilter:
        cargs.append("--despike")
    if despike_threshold is not None:
        cargs.append("--despikethreshold=" + str(despike_threshold))
    if dwell_time is not None:
        cargs.append("--dwell=" + str(dwell_time))
    if dwell_to_asym_ratio is not None:
        cargs.append("--dwelltoasym=" + str(dwell_to_asym_ratio))
    if fmap_in_file is not None:
        cargs.append("--loadfmap=" + execution.input_file(fmap_in_file))
    if fmap_out_file is not None:
        cargs.append("--savefmap=" + execution.input_file(fmap_out_file))
    if forward_warping:
        cargs.append("--forward_warping")
    if fourier_order is not None:
        cargs.append("--fourier=" + str(fourier_order))
    if icorr:
        cargs.append("--icorr")
    if icorr_only:
        cargs.append("--icorronly")
    if in_file is not None:
        cargs.append("--in=" + execution.input_file(in_file))
    if mask_file is not None:
        cargs.append("--mask=" + execution.input_file(mask_file))
    if median_2dfilter:
        cargs.append("--median")
    if no_extend:
        cargs.append("--noextend")
    if no_gap_fill:
        cargs.append("--nofill")
    if nokspace:
        cargs.append("--nokspace")
    if output_type is not None:
        cargs.append(output_type)
    if pava:
        cargs.append("--pava")
    if phase_conjugate:
        cargs.append("--phaseconj")
    if phasemap_in_file is not None:
        cargs.append("--phasemap=" + execution.input_file(phasemap_in_file))
    if poly_order is not None:
        cargs.append("--poly=" + str(poly_order))
    if save_fmap:
        cargs.append("--save_fmap")
    if save_shift:
        cargs.append("--save_shift")
    if save_unmasked_fmap:
        cargs.append("--unmaskfmap")
    if save_unmasked_shift:
        cargs.append("--unmaskshift")
    if shift_in_file is not None:
        cargs.append("--loadshift=" + execution.input_file(shift_in_file))
    if shift_out_file is not None:
        cargs.append("--saveshift=" + execution.input_file(shift_out_file))
    if smooth2d is not None:
        cargs.append("--smooth2=" + str(smooth2d))
    if smooth3d is not None:
        cargs.append("--smooth3=" + str(smooth3d))
    if unwarp_direction is not None:
        cargs.append("--unwarpdir=" + unwarp_direction)
    if unwarped_file is not None:
        cargs.append("--unwarp=" + execution.input_file(unwarped_file))
    if warped_file is not None:
        cargs.append("--warp=" + execution.input_file(warped_file))
    ret = FugueOutputs(
        root=execution.output_file("."),
        fmap_out_file_outfile=execution.output_file(pathlib.Path(fmap_out_file).name) if (fmap_out_file is not None) else None,
        shift_out_file_outfile=execution.output_file(pathlib.Path(shift_out_file).name) if (shift_out_file is not None) else None,
        unwarped_file_outfile=execution.output_file(pathlib.Path(unwarped_file).name) if (unwarped_file is not None) else None,
        warped_file_outfile=execution.output_file(pathlib.Path(warped_file).name) if (warped_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FUGUE_METADATA",
    "FugueOutputs",
    "fugue",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PLUGOUT_TTA_METADATA = Metadata(
    id="eed1ec955438438ba757fc77c80cf0639ea64da3.boutiques",
    name="plugout_tta",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class PlugoutTtaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `plugout_tta(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def plugout_tta(
    host: str | None = None,
    port: int | None = None,
    verbose: bool = False,
    port_offset: int | None = None,
    port_offset_quiet: int | None = None,
    port_offset_bloc: int | None = None,
    max_port_bloc: bool = False,
    max_port_bloc_quiet: bool = False,
    num_assigned_ports: bool = False,
    num_assigned_ports_quiet: bool = False,
    runner: Runner | None = None,
) -> PlugoutTtaOutputs:
    """
    Connects to AFNI and receives notification whenever the user changes Talairach
    coordinates, then drives Netscape to display the closest figures from the
    Talairach-Tournoux atlas.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/plugout_tta.html
    
    Args:
        host: Connect to AFNI running on the specified computer using TCP/IP.\
            Use '-host localhost' to connect on current host with TCP/IP.
        port: Use TCP/IP port number 'pp'. Default is 8005.
        verbose: Verbose mode: prints out progress reports.
        port_offset: Provide a port offset to allow multiple instances of\
            programs to communicate on the same machine. All ports are assigned\
            numbers relative to PORT_OFFSET. Range: [1025, 65500].
        port_offset_quiet: Like -np, but more quiet in the face of adversity.
        port_offset_bloc: Provide a port offset block. Easier to use than -np.\
            Range: [0, MAX_BLOC]. Using this reduces chances of port conflicts.
        max_port_bloc: Print the current value of MAX_BLOC and exit.
        max_port_bloc_quiet: Print MAX_BLOC value and exit quietly.
        num_assigned_ports: Print the number of assigned ports used by AFNI\
            then quit.
        num_assigned_ports_quiet: Print the number of assigned ports used by\
            AFNI then quit quietly.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PlugoutTtaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PLUGOUT_TTA_METADATA)
    cargs = []
    cargs.append("plugout_tta")
    if host is not None:
        cargs.extend([
            "-host",
            host
        ])
    if port is not None:
        cargs.extend([
            "-port",
            str(port)
        ])
    if verbose:
        cargs.append("-v")
    if port_offset is not None:
        cargs.extend([
            "-np",
            str(port_offset)
        ])
    if port_offset_quiet is not None:
        cargs.extend([
            "-npq",
            str(port_offset_quiet)
        ])
    if port_offset_bloc is not None:
        cargs.extend([
            "-npb",
            str(port_offset_bloc)
        ])
    if max_port_bloc:
        cargs.append("-max_port_bloc")
    if max_port_bloc_quiet:
        cargs.append("-max_port_bloc_quiet")
    if num_assigned_ports:
        cargs.append("-num_assigned_ports")
    if num_assigned_ports_quiet:
        cargs.append("-num_assigned_ports_quiet")
    ret = PlugoutTtaOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PLUGOUT_TTA_METADATA",
    "PlugoutTtaOutputs",
    "plugout_tta",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__1D_DIFF_MAG_METADATA = Metadata(
    id="bd7e56bef2922c77f7836179b5ca66d811594b02.boutiques",
    name="@1dDiffMag",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dDiffMagOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__1d_diff_mag(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    result_stdout: OutputPathType
    """The result as a single number displayed on stdout"""


def v__1d_diff_mag(
    infile: InputPathType,
    runner: Runner | None = None,
) -> V1dDiffMagOutputs:
    """
    Computes a magnitude estimate of the first differences of a 1D file.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@1dDiffMag.html
    
    Args:
        infile: 1D input file to compute the magnitude estimate of the first\
            differences.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dDiffMagOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__1D_DIFF_MAG_METADATA)
    cargs = []
    cargs.append("@1dDiffMag")
    cargs.append(execution.input_file(infile))
    ret = V1dDiffMagOutputs(
        root=execution.output_file("."),
        result_stdout=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dDiffMagOutputs",
    "V__1D_DIFF_MAG_METADATA",
    "v__1d_diff_mag",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLINFO_METADATA = Metadata(
    id="6c0d5e1739216d9fa5819a6924339a92e1f8253f.boutiques",
    name="fslinfo",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslinfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslinfo(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fslinfo(
    filename: InputPathType,
    runner: Runner | None = None,
) -> FslinfoOutputs:
    """
    Display information about NIFTI-1 image file.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils
    
    Args:
        filename: Input NIFTI-1 image file (e.g. img.nii.gz).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslinfoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLINFO_METADATA)
    cargs = []
    cargs.append("fslinfo")
    cargs.append(execution.input_file(filename))
    ret = FslinfoOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLINFO_METADATA",
    "FslinfoOutputs",
    "fslinfo",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FILM_CIFTI_METADATA = Metadata(
    id="22269a4481a2fb1ccfa0138931cf5367c9b75cbc.boutiques",
    name="film_cifti",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FilmCiftiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `film_cifti(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_results: OutputPathType
    """Output results file"""


def film_cifti(
    input_filename: InputPathType,
    basename: str,
    left_surface: InputPathType,
    right_surface: InputPathType,
    susan_threshold: float | None = None,
    susan_extent: float | None = None,
    surface_sigma: float | None = None,
    surface_extent: float | None = None,
    film_options: str | None = None,
    runner: Runner | None = None,
) -> FilmCiftiOutputs:
    """
    A tool for statistical analysis of CIFTI files using FILM.
    
    Author: FSL Community
    
    Args:
        input_filename: Input CIFTI file.
        basename: Output basename.
        left_surface: Geometry for left cortex.
        right_surface: Geometry for right cortex.
        susan_threshold: Susan brightness threshold for volumetric analysis\
            (default: 0).
        susan_extent: Susan mask size for volumetric analysis (default: 4).
        surface_sigma: Smoothing sigma for surface analysis (default: 0).
        surface_extent: Smoothing extent for surface analysis (default: 4).
        film_options: Film options to be used with all modes, list must be\
            wrapped by quotes.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FilmCiftiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FILM_CIFTI_METADATA)
    cargs = []
    cargs.append("film_cifti")
    cargs.append("-i")
    cargs.append(execution.input_file(input_filename))
    cargs.append("-o")
    cargs.append(basename)
    cargs.append("-l")
    cargs.append(execution.input_file(left_surface))
    cargs.append("-r")
    cargs.append(execution.input_file(right_surface))
    if susan_threshold is not None:
        cargs.extend([
            "--st",
            str(susan_threshold)
        ])
    if susan_extent is not None:
        cargs.extend([
            "--sm",
            str(susan_extent)
        ])
    if surface_sigma is not None:
        cargs.extend([
            "--ss",
            str(surface_sigma)
        ])
    if surface_extent is not None:
        cargs.extend([
            "--se",
            str(surface_extent)
        ])
    if film_options is not None:
        cargs.extend([
            "--filmOptions",
            film_options
        ])
    ret = FilmCiftiOutputs(
        root=execution.output_file("."),
        output_results=execution.output_file(basename + "_results.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FILM_CIFTI_METADATA",
    "FilmCiftiOutputs",
    "film_cifti",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

QUICK_ALPHA_VALS_PY_METADATA = Metadata(
    id="ed5c29d1849d5d08aef7cc64a2336c02bab2e572.boutiques",
    name="quick.alpha.vals.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class QuickAlphaValsPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `quick_alpha_vals_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    alpha_table: OutputPathType
    """Generated alpha table file"""


def quick_alpha_vals_py(
    max_file: InputPathType,
    niter: int | None = None,
    runner: Runner | None = None,
) -> QuickAlphaValsPyOutputs:
    """
    Generate an alpha table from slow_surf_clustsim.py results.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/quick.alpha.vals.py.html
    
    Args:
        max_file: File containing maximum z values.
        niter: Number of iterations that should be in the z file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `QuickAlphaValsPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(QUICK_ALPHA_VALS_PY_METADATA)
    cargs = []
    cargs.append("quick.alpha.vals.py")
    if niter is not None:
        cargs.extend([
            "-niter",
            str(niter)
        ])
    cargs.append(execution.input_file(max_file))
    ret = QuickAlphaValsPyOutputs(
        root=execution.output_file("."),
        alpha_table=execution.output_file("alpha_table.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "QUICK_ALPHA_VALS_PY_METADATA",
    "QuickAlphaValsPyOutputs",
    "quick_alpha_vals_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REALTIME_RECEIVER_PY_METADATA = Metadata(
    id="9de2be43370c85b484b9455706b62a276bf1580c.boutiques",
    name="realtime_receiver.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class RealtimeReceiverPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `realtime_receiver_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def realtime_receiver_py(
    show_data: typing.Literal["yes", "no"] | None = None,
    write_text_data: str | None = None,
    data_choice: typing.Literal["motion", "motion_norm", "all_extras", "diff_ratio"] | None = None,
    serial_port: str | None = None,
    show_demo_gui: typing.Literal["yes", "no"] | None = None,
    dc_params: list[float] | None = None,
    extras_on_one_line: typing.Literal["yes", "no"] | None = None,
    show_comm_times: bool = False,
    show_demo_data: bool = False,
    swap: bool = False,
    tcp_port: float | None = None,
    verbosity: float | None = None,
    runner: Runner | None = None,
) -> RealtimeReceiverPyOutputs:
    """
    Program to receive and display real-time plugin data from AFNI.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/realtime_receiver.py.html
    
    Args:
        show_data: Display incoming data in terminal window.
        write_text_data: Write data to text file.
        data_choice: Pick which data to send as feedback.
        serial_port: Specify serial port file for feedback data.
        show_demo_gui: Demonstrate a feedback GUI.
        dc_params: Set data_choice parameters, e.g. for diff_ratio, params P1\
            P2.
        extras_on_one_line: Show 'extras' on one line only.
        show_comm_times: Display communication times.
        show_demo_data: Display feedback data in terminal window.
        swap: Swap bytes of incoming data.
        tcp_port: Specify TCP port for incoming connections.
        verbosity: Set the verbosity level.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RealtimeReceiverPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REALTIME_RECEIVER_PY_METADATA)
    cargs = []
    cargs.append("realtime_receiver.py")
    if show_data is not None:
        cargs.extend([
            "-show_data",
            show_data
        ])
    if write_text_data is not None:
        cargs.extend([
            "-write_text_data",
            write_text_data
        ])
    if data_choice is not None:
        cargs.extend([
            "-data_choice",
            data_choice
        ])
    if serial_port is not None:
        cargs.extend([
            "-serial_port",
            serial_port
        ])
    if show_demo_gui is not None:
        cargs.extend([
            "-show_demo_gui",
            show_demo_gui
        ])
    if dc_params is not None:
        cargs.extend([
            "-dc_params",
            *map(str, dc_params)
        ])
    if extras_on_one_line is not None:
        cargs.extend([
            "-extras_on_one_line",
            extras_on_one_line
        ])
    if show_comm_times:
        cargs.append("-show_comm_times")
    if show_demo_data:
        cargs.append("-show_demo_data")
    if swap:
        cargs.append("-swap")
    if tcp_port is not None:
        cargs.extend([
            "-tcp_port",
            str(tcp_port)
        ])
    if verbosity is not None:
        cargs.extend([
            "-verb",
            str(verbosity)
        ])
    ret = RealtimeReceiverPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REALTIME_RECEIVER_PY_METADATA",
    "RealtimeReceiverPyOutputs",
    "realtime_receiver_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_TFCE_METADATA = Metadata(
    id="175a196c8172c1394704595034e0dbfdaa37a2c6.boutiques",
    name="volume-tfce",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class VolumeTfcePresmooth:
    """
    smooth the volume before running TFCE.
    """
    kernel: float
    """the size of the gaussian smoothing kernel in mm, as sigma by default"""
    opt_fwhm: bool = False
    """smoothing kernel size is FWHM, not sigma"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-presmooth")
        cargs.append(str(self.kernel))
        if self.opt_fwhm:
            cargs.append("-fwhm")
        return cargs


@dataclasses.dataclass
class VolumeTfceParameters:
    """
    set parameters for TFCE integral.
    """
    e: float
    """exponent for cluster volume (default 0.5)"""
    h: float
    """exponent for threshold value (default 2.0)"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-parameters")
        cargs.append(str(self.e))
        cargs.append(str(self.h))
        return cargs


class VolumeTfceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_tfce(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_tfce(
    volume_in: InputPathType,
    volume_out: str,
    presmooth: VolumeTfcePresmooth | None = None,
    opt_roi_roi_volume: InputPathType | None = None,
    parameters: VolumeTfceParameters | None = None,
    opt_subvolume_subvolume: str | None = None,
    runner: Runner | None = None,
) -> VolumeTfceOutputs:
    """
    Do tfce on a volume file.
    
    This command does not do any statistical analysis. Please use something like
    PALM if you are just trying to do statistics on your data.
    
    Threshold-free cluster enhancement is a method to increase the relative
    value of regions that would form clusters in a standard thresholding test.
    This is accomplished by evaluating the integral of:
    
    e(h, p)^E * h^H * dh
    
    at each voxel p, where h ranges from 0 to the maximum value in the data, and
    e(h, p) is the extent of the cluster containing voxel p at threshold h.
    Negative values are similarly enhanced by negating the data, running the
    same process, and negating the result.
    
    This method is explained in: Smith SM, Nichols TE., "Threshold-free cluster
    enhancement: addressing problems of smoothing, threshold dependence and
    localisation in cluster inference." Neuroimage. 2009 Jan 1;44(1):83-98.
    PMID: 18501637.
    
    Author: Washington University School of Medicin
    
    Args:
        volume_in: the volume to run TFCE on.
        volume_out: the output volume.
        presmooth: smooth the volume before running TFCE.
        opt_roi_roi_volume: select a region of interest to run TFCE on: the\
            area to run TFCE on, as a volume.
        parameters: set parameters for TFCE integral.
        opt_subvolume_subvolume: select a single subvolume: the subvolume\
            number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeTfceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_TFCE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-tfce")
    cargs.append(execution.input_file(volume_in))
    cargs.append(volume_out)
    if presmooth is not None:
        cargs.extend(presmooth.run(execution))
    if opt_roi_roi_volume is not None:
        cargs.extend([
            "-roi",
            execution.input_file(opt_roi_roi_volume)
        ])
    if parameters is not None:
        cargs.extend(parameters.run(execution))
    if opt_subvolume_subvolume is not None:
        cargs.extend([
            "-subvolume",
            opt_subvolume_subvolume
        ])
    ret = VolumeTfceOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(volume_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_TFCE_METADATA",
    "VolumeTfceOutputs",
    "VolumeTfceParameters",
    "VolumeTfcePresmooth",
    "volume_tfce",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

UBER_TTEST_PY_METADATA = Metadata(
    id="08e79fffe87bea135de5821b34ef14affaeb02a9.boutiques",
    name="uber_ttest.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class UberTtestPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `uber_ttest_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_script: OutputPathType | None
    """Script file generated by the non-GUI option"""


def uber_ttest_py(
    qt_opts: str | None = None,
    help_: bool = False,
    help_gui: bool = False,
    hist: bool = False,
    show_valid_opts: bool = False,
    ver: bool = False,
    no_gui: bool = False,
    program: str | None = None,
    print_script: bool = False,
    save_script: str | None = None,
    mask: InputPathType | None = None,
    set_name_a: str | None = None,
    set_name_b: str | None = None,
    dsets_a: str | None = None,
    dsets_b: str | None = None,
    beta_a: float | None = None,
    beta_b: float | None = None,
    tstat_a: float | None = None,
    tstat_b: float | None = None,
    results_dir: str | None = None,
    runner: Runner | None = None,
) -> UberTtestPyOutputs:
    """
    GUI for group t-test analysis.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/uber_ttest.py.html
    
    Args:
        qt_opts: Pass PyQt4 options directly to the GUI.
        help_: Display help information.
        help_gui: Display help information for the GUI.
        hist: Display the history.
        show_valid_opts: Show valid options.
        ver: Display the version information.
        no_gui: Run without the GUI.
        program: Specify the program to use.
        print_script: Print the script.
        save_script: Save the script to a file.
        mask: Specify the mask file.
        set_name_a: Set name for group A.
        set_name_b: Set name for group B.
        dsets_a: Datasets for group A.
        dsets_b: Datasets for group B.
        beta_a: Beta values for group A.
        beta_b: Beta values for group B.
        tstat_a: T-statistic values for group A.
        tstat_b: T-statistic values for group B.
        results_dir: Directory for saving results.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `UberTtestPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(UBER_TTEST_PY_METADATA)
    cargs = []
    cargs.append("uber_ttest.py")
    if qt_opts is not None:
        cargs.append(qt_opts)
    if help_:
        cargs.append("-help")
    if help_gui:
        cargs.append("-help_gui")
    if hist:
        cargs.append("-hist")
    if show_valid_opts:
        cargs.append("-show_valid_opts")
    if ver:
        cargs.append("-ver")
    if no_gui:
        cargs.append("-no_gui")
    if program is not None:
        cargs.extend([
            "-program",
            program
        ])
    if print_script:
        cargs.append("-print_script")
    if save_script is not None:
        cargs.extend([
            "-save_script",
            save_script
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if set_name_a is not None:
        cargs.extend([
            "-set_name_A",
            set_name_a
        ])
    if set_name_b is not None:
        cargs.extend([
            "-set_name_B",
            set_name_b
        ])
    if dsets_a is not None:
        cargs.extend([
            "-dsets_A",
            dsets_a
        ])
    if dsets_b is not None:
        cargs.extend([
            "-dsets_B",
            dsets_b
        ])
    if beta_a is not None:
        cargs.extend([
            "-beta_A",
            str(beta_a)
        ])
    if beta_b is not None:
        cargs.extend([
            "-beta_B",
            str(beta_b)
        ])
    if tstat_a is not None:
        cargs.extend([
            "-tstat_A",
            str(tstat_a)
        ])
    if tstat_b is not None:
        cargs.extend([
            "-tstat_B",
            str(tstat_b)
        ])
    if results_dir is not None:
        cargs.extend([
            "-results_dir",
            results_dir
        ])
    ret = UberTtestPyOutputs(
        root=execution.output_file("."),
        output_script=execution.output_file(save_script) if (save_script is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "UBER_TTEST_PY_METADATA",
    "UberTtestPyOutputs",
    "uber_ttest_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GET_AFNI_MODEL_PRF_METADATA = Metadata(
    id="ce67383da69c27834bac935d2fc73a96701ca109.boutiques",
    name="get_afni_model_PRF",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class GetAfniModelPrfOutputs(typing.NamedTuple):
    """
    Output object returned when calling `get_afni_model_prf(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def get_afni_model_prf(
    amplitude: float,
    x_coord: float,
    y_coord: float,
    sigma: float,
    runner: Runner | None = None,
) -> GetAfniModelPrfOutputs:
    """
    A tool to get AFNI model parameters assuming a PRF framework.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/get_afni_model_PRF.html
    
    Args:
        amplitude: Amplitude for the AFNI model.
        x_coord: X-coordinate for the AFNI model.
        y_coord: Y-coordinate for the AFNI model.
        sigma: Sigma value for the AFNI model.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GetAfniModelPrfOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GET_AFNI_MODEL_PRF_METADATA)
    cargs = []
    cargs.append("get_afni_model_PRF")
    cargs.append(str(amplitude))
    cargs.append(str(x_coord))
    cargs.append(str(y_coord))
    cargs.append(str(sigma))
    ret = GetAfniModelPrfOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GET_AFNI_MODEL_PRF_METADATA",
    "GetAfniModelPrfOutputs",
    "get_afni_model_prf",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

COMPARE_SURFACES_METADATA = Metadata(
    id="5e9572f48ee61452099e956945950a7fda3d2d6f.boutiques",
    name="CompareSurfaces",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class CompareSurfacesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `compare_surfaces(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    distance_output_file: OutputPathType | None
    """Distance output file."""
    color_output_file: OutputPathType | None
    """Node color output file."""


def compare_surfaces(
    spec_file: InputPathType,
    hemisphere: typing.Literal["L", "R"],
    volume_parent_1: InputPathType,
    volume_parent_2: InputPathType,
    file_prefix: str | None = None,
    one_node: float | None = None,
    node_range: list[float] | None = None,
    no_consistency_check: bool = False,
    no_volreg: bool = False,
    no_transform: bool = False,
    set_environment_variable: str | None = None,
    trace_: bool = False,
    extreme_trace: bool = False,
    no_memory_trace: bool = False,
    yes_memory_trace: bool = False,
    runner: Runner | None = None,
) -> CompareSurfacesOutputs:
    """
    Calculates distance at each node in Surface 1 (S1) to Surface 2 (S2) along the
    local surface normal at each node in S1. Superseded by SurfToSurf.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/CompareSurfaces.html
    
    Args:
        spec_file: File containing surface specification.
        hemisphere: Specify the hemisphere being processed (left or right).
        volume_parent_1: Volume parent BRIK for first surface.
        volume_parent_2: Volume parent BRIK for second surface.
        file_prefix: Prefix for distance and node color output files. Existing\
            file will not be overwritten.
        one_node: Output results for node index only. This option is for\
            debugging.
        node_range: Output results from node istart to node istop only. This\
            option is for debugging.
        no_consistency_check: Skip mesh orientation consistency check. This\
            speeds up the start time so it is useful for debugging runs.
        no_volreg: Ignore any Rotate, Volreg, Tagalign, or WarpDrive\
            transformations present in the Surface Volume.
        no_transform: Same as -novolreg.
        set_environment_variable: Set environment variable ENVname to be\
            ENVvalue. Quotes are necessary.
        trace_: Turns on In/Out debug and Memory tracing.
        extreme_trace: Turns on extreme tracing.
        no_memory_trace: Turn off memory tracing.
        yes_memory_trace: Turn on memory tracing (default).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CompareSurfacesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(COMPARE_SURFACES_METADATA)
    cargs = []
    cargs.append("CompareSurfaces")
    cargs.extend([
        "-spec",
        execution.input_file(spec_file)
    ])
    cargs.extend([
        "-hemi",
        hemisphere
    ])
    cargs.extend([
        "-sv1",
        execution.input_file(volume_parent_1)
    ])
    cargs.extend([
        "-sv2",
        execution.input_file(volume_parent_2)
    ])
    if file_prefix is not None:
        cargs.extend([
            "-prefix",
            file_prefix
        ])
    if one_node is not None:
        cargs.extend([
            "-onenode",
            str(one_node)
        ])
    if node_range is not None:
        cargs.extend([
            "-noderange",
            *map(str, node_range)
        ])
    if no_consistency_check:
        cargs.append("-nocons")
    if no_volreg:
        cargs.append("-novolreg")
    if no_transform:
        cargs.append("-noxform")
    if set_environment_variable is not None:
        cargs.extend([
            "-setenv",
            set_environment_variable
        ])
    if trace_:
        cargs.append("-trace")
    if extreme_trace:
        cargs.append("-TRACE")
    if no_memory_trace:
        cargs.append("-nomall")
    if yes_memory_trace:
        cargs.append("-yesmall")
    ret = CompareSurfacesOutputs(
        root=execution.output_file("."),
        distance_output_file=execution.output_file(file_prefix + "_distance.txt") if (file_prefix is not None) else None,
        color_output_file=execution.output_file(file_prefix + "_color.txt") if (file_prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "COMPARE_SURFACES_METADATA",
    "CompareSurfacesOutputs",
    "compare_surfaces",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SPHARM_DECO_METADATA = Metadata(
    id="5814a4c4423b527f8f11948bcabb27dfbbb8d0d4.boutiques",
    name="SpharmDeco",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SpharmDecoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `spharm_deco(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    harmonics_file: OutputPathType
    """File for harmonics of each order l."""
    beta_coefficients: OutputPathType
    """Beta coefficients for each data column."""
    reconstructed_data: OutputPathType
    """Reconstructed data or surface files named based on PREFIX."""


def spharm_deco(
    runner: Runner | None = None,
) -> SpharmDecoOutputs:
    """
    Spherical Harmonics Decomposition of a surface's coordinates or data.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/SpharmDeco.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SpharmDecoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SPHARM_DECO_METADATA)
    cargs = []
    cargs.append("SpharmDeco")
    cargs.append("<-i_TYPE")
    cargs.append("S>")
    cargs.append("-unit_sph")
    cargs.append("UNIT_SPH_LABEL>")
    cargs.append("<-l")
    cargs.append("L>")
    cargs.append("[<-i_TYPE")
    cargs.append("SD>")
    cargs.append("...")
    cargs.append("|")
    cargs.append("<-data")
    cargs.append("D>]")
    cargs.append("[-bases_prefix")
    cargs.append("BASES]")
    cargs.append("[<-prefix")
    cargs.append("PREFIX>]")
    cargs.append("[<-o_TYPE")
    cargs.append("SDR>")
    cargs.append("...]")
    cargs.append("[-debug")
    cargs.append("DBG]")
    cargs.append("[-sigma")
    cargs.append("s]")
    ret = SpharmDecoOutputs(
        root=execution.output_file("."),
        harmonics_file=execution.output_file("BASES_PREFIX.sph*.1D"),
        beta_coefficients=execution.output_file("PREFIX.beta.col*.1D.dset"),
        reconstructed_data=execution.output_file("<PREFIX>_reconstructed"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SPHARM_DECO_METADATA",
    "SpharmDecoOutputs",
    "spharm_deco",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VECWARP_METADATA = Metadata(
    id="6c6580748aa2429883f7174bbcdc1a5eed33de73.boutiques",
    name="Vecwarp",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VecwarpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `vecwarp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """The output file containing the transformed 3-vectors."""


def vecwarp(
    input_: InputPathType | None = None,
    output: str | None = None,
    force: bool = False,
    runner: Runner | None = None,
) -> VecwarpOutputs:
    """
    Transforms (warps) a list of 3-vectors into another list of 3-vectors according
    to the specified options.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/Vecwarp.html
    
    Args:
        input_: Read input 3-vectors from the file 'iii' (from stdin if 'iii'\
            is '-' or the -input option is missing).
        output: Write the output to file 'ooo' (to stdout if 'ooo' is '-', or\
            if the -output option is missing).
        force: If the output file already exists, use -force to overwrite it.\
            If -force is used, it must come before -output on the command line.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VecwarpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VECWARP_METADATA)
    cargs = []
    cargs.append("Vecwarp")
    cargs.append("[APAR")
    cargs.append("|")
    cargs.append("MATVEC]")
    cargs.append("[FORWARD_FLAG")
    cargs.append("|")
    cargs.append("BACKWARD_FLAG]")
    if input_ is not None:
        cargs.extend([
            "-input",
            execution.input_file(input_)
        ])
    if output is not None:
        cargs.extend([
            "-output",
            output
        ])
    if force:
        cargs.append("-force")
    ret = VecwarpOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output) if (output is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VECWARP_METADATA",
    "VecwarpOutputs",
    "vecwarp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_GEODESIC_DISTANCE_METADATA = Metadata(
    id="038ac8f87c3b794812e70bdbc5c8d11e3e8caddf.boutiques",
    name="surface-geodesic-distance",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceGeodesicDistanceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_geodesic_distance(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def surface_geodesic_distance(
    surface: InputPathType,
    vertex: int,
    metric_out: str,
    opt_naive: bool = False,
    opt_limit_limit_mm: float | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    runner: Runner | None = None,
) -> SurfaceGeodesicDistanceOutputs:
    """
    Compute geodesic distance from one vertex to the entire surface.
    
    Unless -limit is specified, computes the geodesic distance from the
    specified vertex to all others. The result is output as a single column
    metric file, with a value of -1 for vertices that the distance was not
    computed for.
    
    The -corrected-areas option should be used when the input is a group average
    surface - group average surfaces have significantly less surface area than
    individual surfaces do, and therefore distances measured on them would be
    smaller than measuring them on individual surfaces. In this case, the input
    to this option should be a group average of the output of
    -surface-vertex-areas for each subject.
    
    If -naive is not specified, the algorithm uses not just immediate neighbors,
    but also neighbors derived from crawling across pairs of triangles that
    share an edge.
    
    Author: Washington University School of Medicin
    
    Args:
        surface: the surface to compute on.
        vertex: the vertex to compute geodesic distance from.
        metric_out: the output metric.
        opt_naive: use only neighbors, don't crawl triangles (not recommended).
        opt_limit_limit_mm: stop at a certain distance: distance in mm to stop\
            at.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceGeodesicDistanceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_GEODESIC_DISTANCE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-geodesic-distance")
    cargs.append(execution.input_file(surface))
    cargs.append(str(vertex))
    cargs.append(metric_out)
    if opt_naive:
        cargs.append("-naive")
    if opt_limit_limit_mm is not None:
        cargs.extend([
            "-limit",
            str(opt_limit_limit_mm)
        ])
    if opt_corrected_areas_area_metric is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(opt_corrected_areas_area_metric)
        ])
    ret = SurfaceGeodesicDistanceOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(metric_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_GEODESIC_DISTANCE_METADATA",
    "SurfaceGeodesicDistanceOutputs",
    "surface_geodesic_distance",
]
